MsSqlQuery

Struct MsSqlQuery 

pub struct MsSqlQuery<'a>(/* private fields */);

Implementations



impl<'a> MsSqlQuery<'a>

pub fn bind(&mut self, param: impl IntoSql<'a> + 'a)

pub async fn execute_all<'b, C>( self, conn: C, ) -> Result<Vec<<MsSqlQuery<'a> as Query>::ExecuteResult>, Error>
where C: Executor<'b, MsSql>,

Execute multiple queries and return the rows affected from each query, collected into a Vec.

pub async fn execute<'b, C>( self, conn: C, ) -> Result<<MsSqlQuery<'a> as Query>::ExecuteResult, Error>
where C: Executor<'b, MsSql>,

Execute the query and return the total number of rows affected.

pub async fn fetch_many<'b, C>( self, conn: C, ) -> Result<<MsSqlQuery<'a> as Query>::QueryResultStream<'b>, Error>
where C: Executor<'b, MsSql>, 'a: 'b,

Execute multiple queries and return the generated results as a stream from each query, in a stream.

pub fn fetch<'b, C>(self, conn: C) -> <MsSqlQuery<'a> as Query>::RowStream<'b>
where C: Executor<'b, MsSql>, 'a: 'b,

Execute the query and return the generated rows as a stream.

pub async fn fetch_one<'b, C>( self, conn: C, ) -> Result<<<MsSqlQuery<'a> as Query>::Database as Database>::Row, Error>
where C: Executor<'b, MsSql>, 'a: 'b,

Execute the query and returns exactly one row.

pub async fn fetch_optional<'b, C>( self, conn: C, ) -> Result<Option<<<MsSqlQuery<'a> as Query>::Database as Database>::Row>, Error>
where C: Executor<'b, MsSql>, 'a: 'b,

Execute the query and returns at most one row.

pub async fn fetch_all<'b, C>( self, conn: C, ) -> Result<Vec<<<MsSqlQuery<'a> as Query>::Database as Database>::Row>, Error>
where C: Executor<'b, MsSql>, 'a: 'b,

Execute the query and return all the generated rows, collected into a Vec.