Struct MsSqlRow
pub struct MsSqlRow(/* private fields */);Trait Implementations
impl ColumnIndex<MsSqlRow> for &str
impl ColumnIndex<MsSqlRow> for &str
fn index(&self, row: &MsSqlRow) -> Result<usize, Error>
fn index(&self, row: &MsSqlRow) -> Result<usize, Error>
Returns a valid positional index into the row or statement, or,
Error::ColumnIndexOutOfBounds or Error::ColumnNotFound.impl ColumnIndex<MsSqlRow> for usize
impl ColumnIndex<MsSqlRow> for usize
fn index(&self, row: &MsSqlRow) -> Result<usize, Error>
fn index(&self, row: &MsSqlRow) -> Result<usize, Error>
Returns a valid positional index into the row or statement, or,
Error::ColumnIndexOutOfBounds or Error::ColumnNotFound.impl Row for MsSqlRow
impl Row for MsSqlRow
type Database = MsSql
fn columns(&self) -> &[MsSqlColumn] ⓘ
fn columns(&self) -> &[MsSqlColumn] ⓘ
Gets all columns in this statement.
fn column<I>(&self, index: I) -> &<Self::Database as Database>::Columnwhere
I: ColumnIndex<Self>,
fn column<I>(&self, index: I) -> &<Self::Database as Database>::Columnwhere
I: ColumnIndex<Self>,
Gets the column information at
index. Read morefn try_column<I>(
&self,
index: I,
) -> Result<&<Self::Database as Database>::Column, Error>where
I: ColumnIndex<Self>,
fn try_column<I>(
&self,
index: I,
) -> Result<&<Self::Database as Database>::Column, Error>where
I: ColumnIndex<Self>,
Gets the column information at
index or None if out of bounds.fn get<'a, T, I>(&'a self, index: I) -> T
fn get<'a, T, I>(&'a self, index: I) -> T
Index into the database row and decode a single value. Read more